[−][src]Enum libp2p_secio::SecioError
Error at the SECIO layer communication.
Variants
IoError(IoError)I/O error.
ProtobufError(ProtobufError)Protocol buffer error.
HandshakeParsingFailureFailed to parse one of the handshake protobuf messages.
NoSupportIntersectionThere is no protocol supported by both the local and remote hosts.
NonceGenerationFailedFailed to generate nonce.
EphemeralKeyGenerationFailedFailed to generate ephemeral key.
SigningFailureFailed to sign a message with our local private key.
SignatureVerificationFailedThe signature of the exchange packet doesn't verify the remote public key.
SecretGenerationFailedFailed to generate the secret shared key from the ephemeral key.
NonceVerificationFailedThe final check of the handshake failed.
CipherError(LoopError)Error with block cipher.
FrameTooShortThe received frame was of invalid length.
HmacNotMatchingThe hashes of the message didn't match.
InvalidProposition(&'static str)We received an invalid proposition from remote.