[−][src]Struct libp2p_secio::SecioMiddleware
Wraps around an object that implements AsyncRead and AsyncWrite.
Implements Sink and Stream whose items are frames of data. Each frame is encoded
individually, so you are encouraged to group data in few frames if possible.
Methods
impl<S> SecioMiddleware<S> where
S: AsyncRead + AsyncWrite + Send, [src]
S: AsyncRead + AsyncWrite + Send,
pub fn handshake(
socket: S,
config: SecioConfig
) -> impl Future<Item = (SecioMiddleware<S>, PublicKey, Vec<u8>), Error = SecioError>[src]
socket: S,
config: SecioConfig
) -> impl Future<Item = (SecioMiddleware<S>, PublicKey, Vec<u8>), Error = SecioError>
Attempts to perform a handshake on the given socket.
On success, produces a SecioMiddleware that can then be used to encode/decode
communications, plus the public key of the remote, plus the ephemeral public key.